.. change::
    :tags: usecase, sqlite
    :tickets: 8903
    :versions: 2.0.0b4

    Added support for the SQLite backend to reflect the "DEFERRABLE" and
    "INITIALLY" keywords which may be present on a foreign key construct. Pull
    request courtesy Michael Gorven.
